@@ -1,5 +1,5 @@
 //! # Maximum Flow Problem
-#![feature(min_type_alias_impl_trait)]
+#![feature(type_alias_impl_trait)]
 #![feature(generic_associated_types)]
 
 use std::iter;
@@ -11,26 +11,26 @@ use relp_num::NonZero;
 use relp_num::One;
 
 use relp::algorithm::{OptimizationResult, SolveRelaxation};
-use relp::algorithm::two_phase::matrix_provider::column::{Column as ColumnTrait, OrderedColumn};
+use relp::algorithm::two_phase::matrix_provider::column::{Column as ColumnTrait, OrderedColumn, SparseSliceIterator};
 use relp::algorithm::two_phase::matrix_provider::column::identity::IdentityColumn;
 use relp::algorithm::two_phase::matrix_provider::filter::generic_wrapper::IntoFilteredColumn;
 use relp::algorithm::two_phase::matrix_provider::MatrixProvider;
 use relp::algorithm::two_phase::phase_one::PartialInitialBasis;
 use relp::algorithm::two_phase::tableau::inverse_maintenance::carry::basis_inverse_rows::BasisInverseRows;
 use relp::algorithm::two_phase::tableau::inverse_maintenance::carry::Carry;
-use relp::algorithm::utilities::remove_sparse_indices;
+use index_utils::remove_sparse_indices;
 use relp::data::linear_algebra::matrix::{ColumnMajor, SparseMatrix};
 use relp::data::linear_algebra::matrix::MatrixOrder;
 use relp::data::linear_algebra::SparseTuple;
 use relp::data::linear_algebra::traits::{SparseComparator, SparseElement};
 use relp::data::linear_algebra::vector::{DenseVector, SparseVector, Vector};
 use relp::data::linear_program::elements::BoundDirection;
-use relp::data::linear_program::network::representation::{ArcDirection, ArcIncidenceMatrix};
+use relp::data::linear_program::network::representation::{ArcDirection, IncidenceMatrix};
 
 /// Maximum flow problem.
 struct Primal<F> {
     /// For each edge, two values indicating from which value the arc leaves, and where it goes to.
-    arc_incidence_matrix: ArcIncidenceMatrix,
+    arc_incidence_matrix: IncidenceMatrix,
     capacity: DenseVector<F>,
 
     /// Source
@@ -61,7 +61,7 @@ where
         let arcs_before_s = adjacency_matrix.data[..s].iter().map(Vec::len).sum();
         let arcs_leaving_s = adjacency_matrix.data[s].len();
         let s_arc_range = arcs_before_s..(arcs_before_s + arcs_leaving_s);
-        let (arc_incidence_matrix, capacity) = ArcIncidenceMatrix::new(adjacency_matrix, vec![s, t]);
+        let (arc_incidence_matrix, capacity) = IncidenceMatrix::new(adjacency_matrix, vec![s, t]);
 
         Self {
             arc_incidence_matrix,
@@ -90,10 +90,11 @@ struct Column {
 
 impl ColumnTrait for Column {
     type F = ArcDirection;
-    type Iter<'a> = impl Iterator<Item = &'a SparseTuple<Self::F>> + Clone;
+    type Iter<'a> = impl Iterator<Item=SparseTuple<&'a Self::F>> + Clone;
 
     fn iter(&self) -> Self::Iter<'_> {
-        self.constraint_values.iter().chain(iter::once(&self.slack))
+        SparseSliceIterator::new(&self.constraint_values)
+            .chain(iter::once((self.slack.0, &self.slack.1)))
     }
 
     fn index_to_string(&self, i: usize) -> String {
