@@ -6,6 +6,7 @@
 use std::cmp::{max, Ordering};
 use std::fmt;
 
+use index_utils::remove_indices;
 use relp_num::One;
 
 use crate::algorithm::two_phase::matrix_provider::column::{Column, OrderedColumn};
@@ -13,7 +14,6 @@ use crate::algorithm::two_phase::matrix_provider::column::identity::IdentityColu
 use crate::algorithm::two_phase::tableau::inverse_maintenance::{ColumnComputationInfo, ops};
 use crate::algorithm::two_phase::tableau::inverse_maintenance::carry::{BasisInverse, RemoveBasisPart};
 use crate::algorithm::two_phase::tableau::inverse_maintenance::carry::lower_upper::LUDecomposition;
-use crate::algorithm::utilities::remove_indices;
 use crate::data::linear_algebra::traits::SparseElement;
 use crate::data::linear_algebra::vector::{SparseVector, Vector};
 
@@ -75,11 +75,11 @@ where
 
         for (edit_row_index, column_value) in column.iter() {
              match edit_row_index.cmp(&pivot_row_index) {
-                Ordering::Less => rows_left[*edit_row_index]
-                    .add_multiple_of_row(&-column_value, &rows_middle),
+                Ordering::Less => rows_left[edit_row_index]
+                    .add_multiple_of_row(&-column_value, rows_middle),
                 Ordering::Equal => {},
-                Ordering::Greater => rows_right[*edit_row_index - (pivot_row_index + 1)]
-                    .add_multiple_of_row(&-column_value, &rows_middle),
+                Ordering::Greater => rows_right[edit_row_index - (pivot_row_index + 1)]
+                    .add_multiple_of_row(&-column_value, rows_middle),
             }
         }
     }
@@ -111,11 +111,10 @@ where
 
         let inverted_columns = (0..m)
             .map(|i| IdentityColumnStruct((i, One)))
-            .map(|column| lower_upper.generate_column(column))
-            .collect::<Vec<_>>();
+            .map(|column| lower_upper.generate_column(column));
 
         let mut row_major = vec![Vec::new(); m];
-        for (j, column) in inverted_columns.into_iter().enumerate() {
+        for (j, column) in inverted_columns.enumerate() {
             for (i, value) in column.into_column().into_iter() {
                 row_major[i].push((j, value));
             }
@@ -209,7 +208,7 @@ where
 
 impl<F: SparseElement<F>> ColumnComputationInfo<F> for SparseVector<F, F> {
     fn column(&self) -> &SparseVector<F, F> {
-        &self
+        self
     }
 
     fn into_column(self) -> SparseVector<F, F> {
