@@ -8,6 +8,7 @@ use std::fmt::{Debug, Display, Formatter};
 use std::fmt;
 use std::ops::Neg;
 
+use index_utils::remove_indices;
 use relp_num::{NonZero, Signed};
 use relp_num::One;
 
@@ -17,7 +18,6 @@ use crate::algorithm::two_phase::matrix_provider::filter::Filtered;
 use crate::algorithm::two_phase::matrix_provider::MatrixProvider;
 use crate::algorithm::two_phase::tableau::inverse_maintenance::{ColumnComputationInfo, InverseMaintener, ops};
 use crate::algorithm::two_phase::tableau::kind::Kind;
-use crate::algorithm::utilities::remove_indices;
 use crate::data::linear_algebra::SparseTuple;
 use crate::data::linear_algebra::traits::Element;
 use crate::data::linear_algebra::vector::{DenseVector, SparseVector, Vector};
@@ -303,11 +303,11 @@ where
         for (edit_row_index, column_value) in column.iter() {
             match edit_row_index.cmp(&pivot_row_index) {
                 Ordering::Less => {
-                    b_left[*edit_row_index] -= column_value * &*b_middle;
+                    b_left[edit_row_index] -= column_value * &*b_middle;
                 },
                 Ordering::Equal => {},
                 Ordering::Greater => {
-                    b_right[*edit_row_index - (pivot_row_index + 1)] -= column_value * &*b_middle;
+                    b_right[edit_row_index - (pivot_row_index + 1)] -= column_value * &*b_middle;
                 }
             }
         }
@@ -327,7 +327,7 @@ where
     fn update_minus_pi_and_obj(&mut self, pivot_row_index: usize, relative_cost: F) {
         let basis_inverse_row = self.basis_inverse.basis_inverse_row(pivot_row_index);
         for (column_index, value) in basis_inverse_row.iter() {
-            self.minus_pi[*column_index] -= &relative_cost * value;
+            self.minus_pi[column_index] -= &relative_cost * value;
         }
 
         self.minus_objective -= relative_cost * &self.b[pivot_row_index];
@@ -443,7 +443,7 @@ where
             .into_iter().enumerate()
             .filter(|(_, v)| v.is_not_zero())
             .collect::<Vec<_>>();
-        let b_column = SparseColumn { inner: b_data, };
+        let b_column = SparseColumn::new(b_data);
         let mut b_values = vec![F::zero(); provider.nr_rows()];
         for (i, v) in basis_inverse.generate_column(b_column)
             .into_column().into_iter() {
