@@ -10,11 +10,13 @@ use std::iter::{FromIterator, Sum};
 use std::marker::PhantomData;
 use std::ops::{Add, AddAssign, DivAssign, Mul, MulAssign, Neg};
 use std::slice::{Iter, IterMut};
+use std::vec::IntoIter;
 
+use index_utils::remove_sparse_indices;
 use num_traits::{One, Zero};
 use relp_num::NonZero;
 
-use crate::algorithm::utilities::remove_sparse_indices;
+use crate::algorithm::two_phase::matrix_provider::column::{ColumnNumber, SparseSliceIterator};
 use crate::data::linear_algebra::SparseTuple;
 use crate::data::linear_algebra::traits::{SparseComparator, SparseElement};
 use crate::data::linear_algebra::vector::{DenseVector, Vector};
@@ -47,9 +49,13 @@ impl<F, C> Sparse<F, C> {
     pub fn extend(&mut self, extra_len: usize) {
         self.len += extra_len;
     }
+}
 
-    /// Convert the inner data structure into an iterator, consuming the struct.
-    pub fn into_iter(self) -> impl Iterator<Item=SparseTuple<F>> {
+impl<F, C> IntoIterator for Sparse<F, C> {
+    type Item = SparseTuple<F>;
+    type IntoIter = IntoIter<Self::Item>;
+
+    fn into_iter(self) -> Self::IntoIter {
         self.data.into_iter()
     }
 }
@@ -79,7 +85,7 @@ where
         }
     }
 
-    fn sparse_inner_product<'a, H, G: 'a, I: Iterator<Item=&'a SparseTuple<G>>>(&self, column: I) -> H
+    fn sparse_inner_product<'a, H, G: 'a, I: Iterator<Item=SparseTuple<&'a G>>>(&self, column: I) -> H
     where
         H: Zero + AddAssign<F> + Display + Debug,
         G: Display + Debug,
@@ -89,11 +95,11 @@ where
 
         let mut i = 0;
         for (index, value) in column {
-            while i < self.data.len() && self.data[i].0 < *index {
+            while i < self.data.len() && self.data[i].0 < index {
                 i += 1;
             }
 
-            if i < self.data.len() && self.data[i].0 == *index {
+            if i < self.data.len() && self.data[i].0 == index {
                 total += &self.data[i].1 * value;
                 i += 1;
             }
@@ -193,6 +199,16 @@ impl<F: NonZero + SparseElement<C>, C: SparseComparator> FromIterator<F> for Spa
     }
 }
 
+impl<F, C> Sparse<F, C>
+where
+    F: SparseElement<C> + ColumnNumber,
+    C: SparseComparator,
+{
+    pub fn iter(&self) -> SparseSliceIterator<F> {
+        SparseSliceIterator::new(&self.data)
+    }
+}
+
 impl<F, C> Sparse<F, C>
 where
     F: SparseElement<C>,
@@ -246,8 +262,7 @@ where
         let old_data = mem::replace(&mut self.data, Vec::with_capacity(0));
         for (i, value) in old_data {
             while j < other.data.len() && other.data[j].0 < i {
-                let new_value = multiple * &other.data[j].1;
-                new_tuples.push((other.data[j].0, new_value.into()));
+                new_tuples.push((other.data[j].0, multiple * &other.data[j].1));
                 j += 1;
             }
 
